==> daikon-1.0.2.tar.gz: daikon-1.0.2/src/XMLParser/ActionGenerateElement.cpp <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#include <iostream>
#include <string>
#include <stdlib.h>
using namespace std;

#include "../ActionCommand.h"
#include "../ActionFO.h"
#include "../ActionGenerate.h"

#include "ActionGenerateElement.h"
#include "ActionFOElement.h"

ActionGenerateElement::ActionGenerateElement(char* super)
{
    name = "発射";
    superID = super;
    
    objName = NULL;
    x = NULL;
    y = NULL;
    dx = NULL;
    dy = NULL;

    command = NULL;
}

Element* ActionGenerateElement::getChild(char* name, char* super)
{
    if ( strcmp("横位置", name) == 0 ) {
        x = new Element("横位置", super);
        return x;
    }
    else if ( strcmp("縦位置", name) == 0 ) {
        y = new Element("縦位置", super);
        return y;
    }
    if ( strcmp("横初速度", name) == 0 ) {
        dx = new Element("横初速度", super);
        return dx;
    }
    else if ( strcmp("縦初速度", name) == 0 ) {
        dy = new Element("縦初速度", super);
        return dy;
    }
    else if ( strcmp("オブジェクト名", name) == 0 ) {
        objName = new Element("オブジェクト名", super);
        return objName;
    }
    else {
        invalidElement(name);
    }
}

void ActionGenerateElement::endElement()
{
}

double ActionGenerateElement::getX(std::list<std::string>* path)
{
    checkInheritance(getX, x, ActionGenerateElement, 0);
    return atof(x->getValue(NULL).c_str()); 
}
double ActionGenerateElement::getY(std::list<std::string>* path)
{
    checkInheritance(getY, y, ActionGenerateElement, 0);
    return atof(y->getValue(NULL).c_str()); 
}
double ActionGenerateElement::getDX(std::list<std::string>* path)
{
    checkInheritance(getDX, dx, ActionGenerateElement, 0);
    return atof(dx->getValue(NULL).c_str()); 
}
double ActionGenerateElement::getDY(std::list<std::string>* path)
{
    checkInheritance(getDY, dy, ActionGenerateElement, 0);
    return atof(dy->getValue(NULL).c_str()); 
}

ActionFO* ActionGenerateElement::getObj(std::list<std::string>* path)
{
    checkInheritanceNoDefault(getObj, objName, ActionGenerateElement, "発射するオブジェクトが指定されていません。");
    string objName = this->objName->getValue(NULL);
    if ( namedElements.find(objName) == namedElements.end() ) {
        syntaxError("未定義オブジェクト("+objName+")が選択されています。");
    }
    return ((ActionFOElement*)Element::namedElements[objName])->getActionFO();
}

ActionCommand* ActionGenerateElement::getCommand(std::list<std::string>* path)
{
    if ( command != NULL ) { return command; }
    command = ActionGenerate::create(getX(NULL), getY(NULL), getDX(NULL), getDY(NULL), getObj(NULL)->clone());
    return command;
}

==> daikon-1.1.tar.gz: daikon-1.1/src/XMLParser/ActionGenerateElement.cpp <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#include <iostream>
#include <string>
#include <stdlib.h>
using namespace std;

#include "../ActionCommand.h"
#include "../ActionFO.h"
#include "../ActionGenerate.h"

#include "ActionGenerateElement.h"
#include "ActionFOElement.h"

ActionGenerateElement::ActionGenerateElement(char* super)
{
    name = "発射";
    superID = super;
    
    objName = NULL;
    x = NULL;
    y = NULL;
    dx = NULL;
    dy = NULL;

    command = NULL;
}

Element* ActionGenerateElement::getChild(char* name, char* super)
{
    if ( strcmp("横位置", name) == 0 ) {
        x = new Element("横位置", super);
        return x;
    }
    else if ( strcmp("縦位置", name) == 0 ) {
        y = new Element("縦位置", super);
        return y;
    }
    if ( strcmp("横初速度", name) == 0 ) {
        dx = new Element("横初速度", super);
        return dx;
    }
    else if ( strcmp("縦初速度", name) == 0 ) {
        dy = new Element("縦初速度", super);
        return dy;
    }
    else if ( strcmp("オブジェクト名", name) == 0 ) {
        objName = new Element("オブジェクト名", super);
        return objName;
    }
    else {
        invalidElement(name);
    }
}

void ActionGenerateElement::endElement()
{
}

double ActionGenerateElement::getX(std::list<std::string>* path)
{
    checkInheritance(getX, x, ActionGenerateElement, 0);
    return atof(x->getValue(NULL).c_str()); 
}
double ActionGenerateElement::getY(std::list<std::string>* path)
{
    checkInheritance(getY, y, ActionGenerateElement, 0);
    return atof(y->getValue(NULL).c_str()); 
}
double ActionGenerateElement::getDX(std::list<std::string>* path)
{
    checkInheritance(getDX, dx, ActionGenerateElement, 0);
    return atof(dx->getValue(NULL).c_str()); 
}
double ActionGenerateElement::getDY(std::list<std::string>* path)
{
    checkInheritance(getDY, dy, ActionGenerateElement, 0);
    return atof(dy->getValue(NULL).c_str()); 
}

ActionFO* ActionGenerateElement::getObj(std::list<std::string>* path)
{
    checkInheritanceNoDefault(getObj, objName, ActionGenerateElement, "発射するオブジェクトが指定されていません。");
    string objName = this->objName->getValue(NULL);
    if ( namedElements.find(objName) == namedElements.end() ) {
        syntaxError("未定義オブジェクト("+objName+")が選択されています。");
    }
    return ((ActionFOElement*)Element::namedElements[objName])->getActionFO();
}

ActionCommand* ActionGenerateElement::getCommand(std::list<std::string>* path)
{
    if ( command != NULL ) { return command; }
    //command = ActionGenerate::create(getX(NULL), getY(NULL), getDX(NULL), getDY(NULL), getObj(NULL)->clone());
    command = ActionGenerate::create(getX(NULL), getY(NULL), getDX(NULL), getDY(NULL), getObj(NULL));
    return command;
}
